==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpSettingsRoutesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The configuration settings of the paths HTTP requests.
 * @property apiPrefix The prefix that should precede all the authentication/authorization paths.
 */
public data class HttpSettingsRoutesArgs(
    public val apiPrefix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs =
        com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs.builder()
            .apiPrefix(apiPrefix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpSettingsRoutesArgs].
 */
@PulumiTagMarker
public class HttpSettingsRoutesArgsBuilder internal constructor() {
    private var apiPrefix: Output<String>? = null

    /**
     * @param value The prefix that should precede all the authentication/authorization paths.
     */
    @JvmName("alrgcfwbfexmonxd")
    public suspend fun apiPrefix(`value`: Output<String>) {
        this.apiPrefix = value
    }

    /**
     * @param value The prefix that should precede all the authentication/authorization paths.
     */
    @JvmName("dwlxvxecsqqmwnbw")
    public suspend fun apiPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiPrefix = mapped
    }

    internal fun build(): HttpSettingsRoutesArgs = HttpSettingsRoutesArgs(
        apiPrefix = apiPrefix,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpSettingsRoutesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The configuration settings of the paths HTTP requests.
 * @property apiPrefix The prefix that should precede all the authentication/authorization paths.
 */
public data class HttpSettingsRoutesArgs(
    public val apiPrefix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs =
        com.pulumi.azurenative.app.inputs.HttpSettingsRoutesArgs.builder()
            .apiPrefix(apiPrefix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpSettingsRoutesArgs].
 */
@PulumiTagMarker
public class HttpSettingsRoutesArgsBuilder internal constructor() {
    private var apiPrefix: Output<String>? = null

    /**
     * @param value The prefix that should precede all the authentication/authorization paths.
     */
    @JvmName("lykhwykyaqnygped")
    public suspend fun apiPrefix(`value`: Output<String>) {
        this.apiPrefix = value
    }

    /**
     * @param value The prefix that should precede all the authentication/authorization paths.
     */
    @JvmName("dmsfpoecfoaqikej")
    public suspend fun apiPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiPrefix = mapped
    }

    internal fun build(): HttpSettingsRoutesArgs = HttpSettingsRoutesArgs(
        apiPrefix = apiPrefix,
    )
}
